/* Copyright (C) 2025 Wildfire Games.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#include "precompiled.h"

#include "lib/sysdep/numa.h"

#include "lib/bits.h"
#include "lib/debug.h"
#include "lib/sysdep/os_cpu.h"

#include <cstddef>
#include <cstdint>

size_t numa_NumNodes()
{
	return 1;
}

size_t numa_NodeFromProcessor(size_t /*processor*/)
{
	return 0;
}

uintptr_t numa_ProcessorMaskFromNode(size_t node)
{
	ENSURE(node == 0);
	return bit_mask<uintptr_t>(os_cpu_NumProcessors());
}

size_t numa_AvailableMemory(size_t node)
{
	ENSURE(node == 0);
	return os_cpu_MemoryAvailable();
}

double numa_Factor()
{
	return 1.0;
}

bool numa_IsMemoryInterleaved()
{
	return false;
}
